@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "16.0.2+7-67" },
-            { "jdk", "16.0.2" },
-            { "release", "16.0.2" },
+            { "full", "17.0.2+8" },
+            { "jdk", "17.0.2" },
+            { "release", "17.0.2" },
         };
     }
 }
